package XML::Grammar::Screenplay::API::ImageListDoc;
$XML::Grammar::Screenplay::API::ImageListDoc::VERSION = '0.32.0';
use strict;
use warnings;

use MooX 'late';

extends('XML::Grammar::Screenplay::FromProto');

has ['_dom'] => ( is => 'rw' );
has ['_xml'] => ( is => 'rw' );

sub list_images
{
    my ($self) = @_;
    my %found;

    my $xpc = XML::LibXML::XPathContext->new();
    $xpc->registerNs( 's',
q{http://web-cpan.berlios.de/modules/XML-Grammar-Screenplay/screenplay-xml-0.2/}
    );
    foreach
        my $img ( $xpc->find( q{//s:image}, $self->_dom() )->get_nodelist() )
    {
        ++$found{ $img->getAttribute('url') };
    }

    return [
        map {
            XML::Grammar::Screenplay::API::ImageListDoc::_Record->new(
                {
                    _uri => $_,
                }
            )
            }
            sort keys(%found)
    ];
}

1;

package XML::Grammar::Screenplay::API::ImageListDoc::_Record;
$XML::Grammar::Screenplay::API::ImageListDoc::_Record::VERSION = '0.32.0';
use MooX 'late';

has '_uri' => ( is => 'ro' );

sub uri
{
    my ( $self, ) = @_;

    return $self->_uri();
}

1;

# __END__
# # Below is stub documentation for your module. You'd better edit it!

__END__

=pod

=encoding UTF-8

=head1 NAME

=head1 VERSION

version 0.32.0

=head1 SYNOPSIS

=head1 DESCRIPTION

=head1 METHODS

=head2 my $aref = $self->list_images()

Returns an array reference containing a list of image-encapsulating objects.
One can call each object's C<< $image_obj->url() >> method to get its URL as a
string.

=head2

=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan

=head1 SUPPORT

=head2 Websites

The following websites have more information about this module, and may be of help to you. As always,
in addition to those websites please use your favorite search engine to discover more resources.

=over 4

=item *

MetaCPAN

A modern, open-source CPAN search engine, useful to view POD in HTML format.

L<https://metacpan.org/release/XML-Grammar-Fiction>

=item *

RT: CPAN's Bug Tracker

The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.

L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-Grammar-Fiction>

=item *

CPANTS

The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.

L<http://cpants.cpanauthors.org/dist/XML-Grammar-Fiction>

=item *

CPAN Testers

The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.

L<http://www.cpantesters.org/distro/X/XML-Grammar-Fiction>

=item *

CPAN Testers Matrix

The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.

L<http://matrix.cpantesters.org/?dist=XML-Grammar-Fiction>

=item *

CPAN Testers Dependencies

The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.

L<http://deps.cpantesters.org/?module=XML::Grammar::Fiction>

=back

=head2 Bugs / Feature Requests

Please report any bugs or feature requests by email to C<bug-xml-grammar-fiction at rt.cpan.org>, or through
the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=XML-Grammar-Fiction>. You will be automatically notified of any
progress on the request by the system.

=head2 Source Code

The code is open to the world, and available for you to hack on. Please feel free to browse it and play
with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
from your repository :)

L<https://github.com/shlomif/fiction-xml>

  git clone git://github.com/shlomif/fiction-xml.git

=head1 AUTHOR

Shlomi Fish <shlomif@cpan.org>

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website
L<https://github.com/shlomif/fiction-xml/issues>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2007 by Shlomi Fish.

This is free software, licensed under:

  The MIT (X11) License

=cut
